SetupJavaX — setupjavax documentation

# SetupJavaX

# Abstract

Modern landscapes of information infrastructures are commonly designed and organized as stacks of runtime service environments. The technical architecture of the service stacks consists of a wide range of heterogenous landscapes of components frequently requiring adaptation and mediation with extended special installations by setuptools / distutils via setup.py. This frequently requires the integration of components implemented of multiple programming languages. A popular component for the integration of Python and Java is Jython [Jython] with support of intermixed modules. Jython extensions are supported by various Java based application servers, e.g. by JBoss Application Server, Oracle Weblogic Server, and IBM WebSphere Application Server.

The Jython implementation requires frequently compiled native Java modules as extentions, which require to be compiled and packaged in combination with Python modules for distribution.

Figure: Installation of Service Layers more…

The setupjavax supports commands for the compilation and packaging of Java packages in conjunction with Jython.

For tested standard OS and distributions see help on installation / Tested OS and Python Implementations.

Shortcuts

- SetupJavaX
- apidoc
- apiref

Documentation

- 1. Abstract
- 2. Platform Support
- 3. Blueprint
- 4. Command Line Interface
- 5. Documents
- 6. Modules
- 7. Indices and tables
- 8. Resources
- 9. Install
- 10. External References
- 11. Licenses

Application

- Howto
- FAQ

# Resources

Home

- Sourceforge.net: https://sourceforge.net/projects/setupjavax/

Online Documents

- Sourceforge.net: https://setupjavax.sourceforge.io/

Runtime Repository

- Python Package Index: https://pypi.org/project/setupjavax/

Downloads

- bitbucket.org: https://bitbucket.org/acue/setupjavax/

- github.com: https://github.com/ArnoCan/setupjavax/

- Python Package Index: https://pypi.org/project/setupjavax/

- Sourceforge.net: https://sourceforge.net/projects/setupjavax/

# Licenses

## Product

Product Data

- MISSION=Support Java extensions for setuptools / distutils.

- AUTHOR=Arno-Can Uestuensoez

- PROJECT=setupjavax

- COPYRIGHT=(C)2019 Arno-Can Uestuensoez

- LICENSE=Artistic-License-2.0 + Forced-Fairplay-Constraints

- VERSION=0.1.37

- RELEASE=0.1.37

- STATUS=Unknown

- BUILDDATE=2019.12.09-05:53

[xkcd] Support the OpenSource Authors

## Modified Artistic License

The modified Artistic License is based on the ArtisticLicense2.0, but adds the amendmend of “Forced-Fairplay-Constraints” for peer-to-peer fairplay rules. The modification restricts, and even revokes the permission including the open source attribution in case of breaches, including the past.

>     License:ModifiedArtisticLicense2.0 = ArtisticLicense2.0 + Forced-Fairplay-Constraints
>     From Ingenieurbuero Arno-Can Uestuensoez
>     Name  ModifiedArtisticLicense2.0

This is perfectly allright, as you may refer to cases like the faith of Andreas Pavel [AndreasPavel], or even my own - UnifiedSessionsManager (C) 2008 Arno-Can Uestuensoez [UnifiedSessionsManager] - the first multivendor cloud management system, capable of distributed hybrid clouds including virtual desktops. The UnifiedSessionsManager was originally licensed as GPL3.

So the software is OpenSource as long as you comply to basic rules - else not.

- Artistic-License-2.0(base license): ArtisticLicense20

- Forced-Fairplay-Constraints(amendments): licenses-amendments